@@ -19,8 +19,8 @@
 #include <KProcessList>
 #include <KService>
 
-#include <taskmanager/abstracttasksmodel.h>
-#include <taskmanager/windowtasksmodel.h>
+#include <abstracttasksmodel.h>
+#include <windowtasksmodel.h>
 
 #include "pluginmanager.h"
 
@@ -132,7 +132,7 @@ Settings::Settings()
         connect(m_tasksModel,
                 &TaskManager::WindowTasksModel::dataChanged,
                 this,
-                [this](const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles) {
+                [this](const QModelIndex &topLeft, const QModelIndex &bottomRight, const QList<int> &roles) {
                     // TODO should we bother checking this, even?
                     if (topLeft.parent().isValid() || bottomRight.parent().isValid() || topLeft.column() != 0 || bottomRight.column() != 0) {
                         return;
@@ -189,7 +189,7 @@ void Settings::handleData(const QString &event, const QJsonObject &data)
 
         Q_EMIT changed(data);
     } else if (event == QLatin1String("openKRunnerSettings")) {
-        QProcess::startDetached(QStringLiteral("systemsettings5"), {QStringLiteral("kcm_plasmasearch")});
+        QProcess::startDetached(QStringLiteral("systemsettings"), {QStringLiteral("kcm_plasmasearch")});
     } else if (event == QLatin1String("setEnvironment")) {
         setEnvironmentFromExtensionMessage(data);
     }
@@ -314,3 +314,5 @@ QJsonObject Settings::settingsForPlugin(const QString &subsystem) const
 {
     return m_settings.value(subsystem).toObject();
 }
+
+#include "moc_settings.cpp"
